@@ -34,7 +34,5 @@
 
 /* AutoInit dependencies.  */
 #include "vtkFiltersExtractionModule.h"
-#include "vtkFiltersGeneralModule.h"
-#include "vtkFiltersParallelModule.h"
 
 #endif
